## Agent Metadata
- **Agent Type**: {agent_type}
- **Run ID**: {run_id}
- **Sprint**: {sprint_name}
- **Teammate**: {teammate_name}

## PRD Scope
| FR | Status |
|----|--------|
{fr_status_rows}

## Automated Checks
- **Build**: {build_status}
- **mypy**: {mypy_status}
- **Coverage**: {coverage_pct}% ({coverage_delta})
- **Tests Run**: {test_count}

## Change Summary
- **Files Changed**: {files_changed}
- **Lines Added**: +{lines_added}
- **Lines Removed**: -{lines_removed}

## WHY
{why_lines}

## Known Gaps
{known_gaps}
